Module icmp

Module icmp 

Structs

IcmpDstUnreachable
For ICMP Type 3 “Destination Unreachable” Message (RFC 792) with support for PMTUD (RFC 1191) Contains 2 unused bytes followed by a Next-Hop MTU field indicating the maximum transmission unit of the next-hop network on which fragmentation is required.
IcmpHdrPhoturis
For ICMP Type 40 (PHOTURIS) Message (RFC 2521) Contains 2 “Reserved” bytes followed by the Security Parameters Index used for a security association between two peers. Also includes a 2-byte pointer field indicating where in the message the error was detected.
IcmpIdSequence
Represents the ID and sequence fields, used by the following ICMP Types:
IcmpPacketTooBig
Represents the Packet Too Big message.
IcmpTimestampMsgPart
Represents the variable length portion of a Timestamp Request/Reply message (RFC 792) that follows the ICMP header.
IcmpTraceroute
For ICMP Type 30 “Traceroute” Message (RFC 1393) Contains a 16-bit ID Number field used by the source to match responses to outgoing requests followed by 2 unused bytes to make a total of 4 bytes.
IcmpTracerouteMsgPart
Represents the variable length portion of a Traceroute message (RFC 1393) that follows the ICMP header.
Icmpv4Hdr
Represents an ICMP header as defined in RFC 792. The header consists of a type and code field identifying the message type, a checksum for error detection, and a data field whose format depends on the message type.
Icmpv4ParamProblem
For ICMP Type 12 “Parameter Problem” Message (RFC 792) Contains a pointer to the byte in the original datagram that caused the error and 3 bytes of unused padding to make the field a total of 4 bytes.
Icmpv4Redirect
Represents the payload of an ICMP Redirect message (Type 5). The four bytes encode the gateway internet address in network byte order.
Icmpv6Hdr
Represents an ICMPv6 header as defined in RFC 4443. The header consists of a type and code field identifying the message type, a checksum for error detection, and a data field whose format depends on the message type.
Icmpv6ParamProblem
Represents the Parameter Problem message for ICMPv6.
Icmpv6Redirect
Represents the Redirect message.

Enums

Icmp
An enum representing either an ICMPv4 or ICMPv6 header.
IcmpError
An enum representing errors that can occur while processing ICMP headers.
Icmpv4HdrData
Strongly typed view of Icmpv4Hdr::data.
Icmpv4HdrDataMut
Mutable strongly typed view of Icmpv4Hdr::data.
Icmpv4Type
Icmpv6HdrData
Strongly typed view of Icmpv6Hdr::data.
Icmpv6HdrDataMut
Mutable strongly typed view of Icmpv6Hdr::data.
Icmpv6Type