IcmpDstUnreachable

Struct IcmpDstUnreachable 

#[repr(C)]
pub struct IcmpDstUnreachable { pub _unused: [u8; 2], pub mtu: [u8; 2], }
For ICMP Type 3 “Destination Unreachable” Message (RFC 792) with support for PMTUD (RFC 1191) Contains 2 unused bytes followed by a Next-Hop MTU field indicating the maximum transmission unit of the next-hop network on which fragmentation is required.

Fields

_unused: [u8; 2]mtu: [u8; 2]

Implementations

Source

impl IcmpDstUnreachable

pub fn mtu(&self) -> u16

Returns the Next-Hop MTU field from a Destination Unreachable message in host byte order. Used for Path MTU Discovery (RFC 1191).

Safety

Caller must ensure ICMP type is 3 (Destination Unreachable) before calling this function. Accessing the dst_unreachable field with other ICMP types may result in undefined behavior.

pub fn set_mtu(&mut self, mtu: u16)