#[repr(C)]pub struct IcmpHdrPhoturis {
pub reserved_spi: [u8; 2],
pub pointer: [u8; 2],
}Expand description
For ICMP Type 40 (PHOTURIS) Message (RFC 2521) Contains 2 “Reserved” bytes followed by the Security Parameters Index used for a security association between two peers. Also includes a 2-byte pointer field indicating where in the message the error was detected.
Fields
reserved_spi: [u8; 2]pointer: [u8; 2]Implementations
Sourceimpl IcmpHdrPhoturis
impl IcmpHdrPhoturis
pub fn reserved_spi(&self) -> u16
pub fn set_reserved_spi(&mut self, spi: u16)
pub fn pointer(&self) -> u16
pub fn set_pointer(&mut self, pointer: u16)