#[repr(C)]pub struct Icmpv4ParamProblem {
pub pointer: u8,
pub _unused: [u8; 3],
}Expand description
For ICMP Type 12 “Parameter Problem” Message (RFC 792) Contains a pointer to the byte in the original datagram that caused the error and 3 bytes of unused padding to make the field a total of 4 bytes.
Fields
pointer: u8_unused: [u8; 3]Implementations