Icmpv6Hdr

Struct Icmpv6Hdr 

#[repr(C)]
pub struct Icmpv6Hdr { pub type_: u8, pub code: u8, pub check: [u8; 2], pub data: [u8; 4], }
Represents an ICMPv6 header as defined in RFC 4443. The header consists of a type and code field identifying the message type, a checksum for error detection, and a data field whose format depends on the message type.

The type_ field identifies the general category of message, such as:

  • 1: Destination Unreachable
  • 2: Packet Too Big
  • 3: Time Exceeded
  • 4: Parameter Problem
  • 128: Echo Request
  • 129: Echo Reply

The code field provides additional context for the message type.

The check field contains a checksum calculated over an IPv6 pseudo-header, the ICMPv6 header, and its payload.

The data field contains type-specific data such as echo identifiers/sequence numbers, MTU values, or pointers to errors in received packets.

Fields

type_: u8code: u8check: [u8; 2]data: [u8; 4]

Implementations

Source

impl Icmpv6Hdr

pub const LEN: usize

pub fn icmp_type(&self) -> Result<Icmpv6Type, IcmpError>

pub fn checksum(&self) -> u16

Returns the ICMPv6 header checksum value in host byte order. This field is used to detect corruption in the ICMPv6 header and payload.

pub fn set_checksum(&mut self, checksum: u16)

Sets the ICMPv6 header checksum field to the given value. The checksum value should be calculated over the pseudo-header, ICMPv6 header, and payload according to RFC 4443. The value will be stored in network byte order.

pub fn data(&self) -> Result<Icmpv6HdrData<'_>, IcmpError>

Returns a type-safe view over the data bytes based on the ICMPv6 type.

pub fn data_mut(&mut self) -> Result<Icmpv6HdrDataMut<'_>, IcmpError>

Returns a mutable type-safe view over the data bytes based on the ICMPv6 type.

Source

impl Icmpv6Hdr

These are the unsafe alternatives to the safe functions on Icmpv6Hdr that do prevent undefined behavior.

pub unsafe fn id_sequence_unchecked(&self) -> &IcmpIdSequence

Returns a reference to the ID and sequence fields.

Safety

Caller must ensure ICMPv6 type is 128 (Echo Request) or 129 (Echo Reply) before calling this function. Accessing the fields with other ICMPv6 types may result in undefined behavior.

pub unsafe fn id_sequence_mut_unchecked(&mut self) -> &mut IcmpIdSequence

Returns a mutable reference to the ID and sequence fields.

Safety

Caller must ensure ICMPv6 type is 128 (Echo Request) or 129 (Echo Reply) before calling this function. Accessing the fields with other ICMPv6 types may result in undefined behavior.

pub unsafe fn packet_too_big_unchecked(&self) -> &IcmpPacketTooBig

Returns a reference to the Packet Too Big message (Type 2).

Safety

Caller must ensure ICMPv6 type is 2 (Packet Too Big) before calling. Accessing the fields with other types may result in undefined behavior.

pub unsafe fn packet_too_big_mut_unchecked(&mut self) -> &mut IcmpPacketTooBig

Returns a mutable reference to the Packet Too Big message (Type 2).

Safety

Caller must ensure ICMPv6 type is 2 (Packet Too Big) before calling. Accessing the fields with other types may result in undefined behavior.

pub unsafe fn parameter_problem_unchecked(&self) -> &Icmpv6ParamProblem

Returns a reference to the Parameter Problem message (Type 4).

Safety

Caller must ensure ICMPv6 type is 4 (Parameter Problem) before calling. Accessing the fields with other types may result in undefined behavior.

pub unsafe fn parameter_problem_mut_unchecked( &mut self, ) -> &mut Icmpv6ParamProblem

Returns a mutable reference to the Parameter Problem message (Type 4).

Safety

Caller must ensure ICMPv6 type is 4 (Parameter Problem) before calling. Accessing the fields with other types may result in undefined behavior.

pub unsafe fn redirect_unchecked(&self) -> &Icmpv6Redirect

Returns a reference to the ICMPv6 Redirect message (Type 137). This field is currently unused and MUST be initialized to zeros by the sender.

Safety

Caller must ensure ICMPv6 type is 137 (Redirect) before calling. Accessing redirect fields with other types may result in undefined behavior.

pub unsafe fn redirect_mut_unchecked(&mut self) -> &mut Icmpv6Redirect

Returns a mutable reference to the ICMPv6 Redirect message (Type 137). This field is currently unused and MUST be initialized to zeros by the sender.

Safety

Caller must ensure ICMPv6 type is 137 (Redirect) before calling. Accessing redirect fields with other types may result in undefined behavior.