#[repr(C)]pub struct IcmpTimestampMsgPart {
pub originate_timestamp: [u8; 4],
pub receive_timestamp: [u8; 4],
pub transmit_timestamp: [u8; 4],
}Expand description
Represents the variable length portion of a Timestamp Request/Reply message (RFC 792) that follows the ICMP header.
Timestamps are milliseconds since midnight UT and are stored in network byte order.
Example
use aya_ebpf::programs::TcContext;
use network_types::eth::EthHdr;
use network_types::icmp::{Icmpv4Hdr, IcmpError, Icmpv4HdrData, IcmpTimestampMsgPart};
use network_types::ip::Ipv4Hdr;
fn handle_icmp_timestamp(ctx: &TcContext) -> Result<u32, IcmpError> {
// Parse the ICMP header from start of payload
let icmp_start = ctx.data() + EthHdr::LEN + Ipv4Hdr::LEN;
let icmp_hdr: *mut Icmpv4Hdr = icmp_start as *mut Icmpv4Hdr;
// Timestamp request/reply share the same echo layout; ensure the type matches
match unsafe { (*icmp_hdr).data()? } {
Icmpv4HdrData::Timestamp(id_seq)
| Icmpv4HdrData::TimestampReply(id_seq) => {
let timestamps_ptr_location = icmp_start + Icmpv4Hdr::LEN;
let timestamps: *const IcmpTimestampMsgPart =
timestamps_ptr_location as *const IcmpTimestampMsgPart;
let _id = id_seq.id();
let _sequence = id_seq.sequence();
unsafe {
let _orig = (*timestamps).originate_timestamp();
let _recv = (*timestamps).receive_timestamp();
let _xmit = (*timestamps).transmit_timestamp();
// Use the timestamp fields as needed.
}
},
_ => {},
}
Ok(0)
}Fields
originate_timestamp: [u8; 4]receive_timestamp: [u8; 4]transmit_timestamp: [u8; 4]Implementations
Sourceimpl IcmpTimestampMsgPart
impl IcmpTimestampMsgPart
pub const LEN: usize
Sourcepub fn originate_timestamp(&self) -> u32
pub fn originate_timestamp(&self) -> u32
Returns the originate timestamp in host byte order (milliseconds since midnight UT)
Sourcepub fn set_originate_timestamp(&mut self, timestamp: u32)
pub fn set_originate_timestamp(&mut self, timestamp: u32)
Sets the originate timestamp field (milliseconds since midnight UT). The value will be stored in network byte order.
Sourcepub fn receive_timestamp(&self) -> u32
pub fn receive_timestamp(&self) -> u32
Returns the receive timestamp in host byte order (milliseconds since midnight UT)
Sourcepub fn set_receive_timestamp(&mut self, timestamp: u32)
pub fn set_receive_timestamp(&mut self, timestamp: u32)
Sets the receive timestamp field (milliseconds since midnight UT). The value will be stored in network byte order.
Sourcepub fn transmit_timestamp(&self) -> u32
pub fn transmit_timestamp(&self) -> u32
Returns the transmit timestamp in host byte order (milliseconds since midnight UT)
Sourcepub fn set_transmit_timestamp(&mut self, timestamp: u32)
pub fn set_transmit_timestamp(&mut self, timestamp: u32)
Sets the transmit timestamp field (milliseconds since midnight UT). The value will be stored in network byte order.